"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tsconfig_1 = require("tsconfig");
function escapeRegExp(text) {
    // we don't excape * in tsconfig paths
    // but we should escape other special characters
    return text.replace(/[-[\]{}()+?.,\\^$|#\s]/g, '\\$&');
}
exports.getJestMappersFromTSConfig = (tsconfigPath) => {
    const { config } = tsconfig_1.loadSync('', tsconfigPath);
    if (!config.compilerOptions || !config.compilerOptions.paths) {
        throw new Error('paths field not found in tsconfig compiler options');
    }
    const paths = config.compilerOptions.paths;
    const moduleNameMapper = {};
    for (let [key, valueArray] of Object.entries(paths)) {
        if (!Array.isArray(valueArray) || valueArray.length !== 1) {
            throw new Error(`paths should be an array with exactly one element for mapping to work.\n Check value of: ${key}`);
        }
        const [value] = valueArray;
        const source = escapeRegExp(key).replace(/\*/, "(.*)");
        const path = `<rootDir>/${value.replace(/\*/, "$1")}`;
        moduleNameMapper[source] = path;
    }
    return moduleNameMapper;
};
exports.default = exports.getJestMappersFromTSConfig;
module.exports = exports.getJestMappersFromTSConfig;
//# sourceMappingURL=index.js.map